<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns="http://www.ieee.org/11073/nomenclature" xpath-default-namespace="http://www.ieee.org/11073/nomenclature">
<!-- makeHTMLfromSimpleXML.3c.xsl -->
<!-- Paul Schluter  2015-12-02T16 -->
<!-- Create HTML table from Simple XML file  -->
<!-- 
	Revision History:
	[1a] Initial version.
	[1b] Works, including markup processing.
	[1c] Added very light grey shading to "retired" and "deprecated" term-rows with # PartCode prefix.
	[2a] Support hierarchical <table> element.
	[2a] Output to "http://www.ieee.org/11073/nomenclature" namespace.
	[2b] Now expects <standard> rather than the previous <tables> as root node name.
	[3a] Templates now remove underscore _formatting_ and strikethrough _text_ to match P1 proof.
	[3b] Uses italic font for second and subsequent MDC REFIDs (.x5et. or later) for readability.
	[3b] Supports <br style="mso-data-placement:same-cell;"/> to keep line breaks together in cell when copying HTML to Excel.
	[3c] Print XML <header> information at beginning.

	Future:
	1.  Provide more complete description of markup formatting options using xsl:template priority.
-->

	<xsl:output method="html"/>

	<xsl:template match="/">
		<html>
			<head>
				<meta http-equiv="Content-Type" content="text/html;charset=UTF-8" />
			</head>

			<body>
			
				IEEE Title: <b><xsl:value-of select="standard/header/title"/></b><br/>
				IEEE Designation: <b><xsl:value-of select="standard/header/ieee-designation"/></b><br/>
				Publication Date: <xsl:value-of select="standard/header/pubdate"/><br/>
				<xsl:value-of select="standard/header/copyright"/><br/>
				<br/>
				<br/>

				<xsl:for-each-group select="standard/table/*" group-starting-with="standard/table/tableTitle">
				
					<xsl:variable name="nCol" select="count(following-sibling::term[1]/child::*)"/>
					
					<table border="1" cellpadding="2" cellspacing="0">
						<tbody>
						
							<xsl:for-each select="current-group()">
								<xsl:choose>
									
									<!-- First row of current-group is title row:  print Table title followed by column headings. -->
									<xsl:when test="position() = 1">
										<tr><td colspan="{$nCol}" bgcolor="#F0F0F0"><b><xsl:value-of select="text()"/></b></td></tr>
										<tr>
											<xsl:for-each select="following-sibling::term[1]/child::*">
												<td bgcolor="#F0F0F0"><b><xsl:value-of select="name()"/></b></td>
											</xsl:for-each>
										</tr>
									</xsl:when>
									
									<!-- If one or zero child elements, assume a table section or note row -->
									<xsl:when test="count(child::*) le 1">
										<tr><td colspan="{$nCol}" bgcolor="#F0F0F0"><xsl:value-of select="text()"/></td></tr>
									</xsl:when>
									
									<!-- Otherwise, print all cells in row.  Use very light grey shading if PartCode has # prefix. -->							
									<xsl:otherwise>
										<xsl:choose>
											<xsl:when test="starts-with(PartCode, '#')">
												<tr bgcolor="#F8F8F8">
													<xsl:for-each select="*">
														<td><xsl:apply-templates/></td>
													</xsl:for-each>
												</tr>
											</xsl:when>
											<xsl:otherwise>
												<tr>
													<xsl:for-each select="*">
														<xsl:choose>
															<xsl:when test="local-name() eq 'REFID'">
																<td>
																	<xsl:for-each select="tokenize(normalize-space(string-join(.//text(),'')),'\s')">
																		<xsl:choose>
																			<xsl:when test="position() eq 1"><xsl:value-of select="."/></xsl:when>
																			<xsl:otherwise><xsl:value-of select="' '"/><i><xsl:value-of select="."/></i></xsl:otherwise>
																		</xsl:choose>
																	</xsl:for-each>
																</td>
															</xsl:when>
															<xsl:otherwise>
																<td><xsl:apply-templates/></td>
															</xsl:otherwise>
														</xsl:choose>
													</xsl:for-each>
												</tr>																					
											</xsl:otherwise>
										</xsl:choose>
									</xsl:otherwise>		
									
								</xsl:choose>
							</xsl:for-each>
						
						</tbody>
					</table>
				
					<br/>
					<br/>
				
				</xsl:for-each-group>
			</body>			

		</html>
	</xsl:template>				
	
	<!-- Process <i>, <b>, <s>, <u>, <sub>, <sup> and <br> tags -->
	<xsl:template match="i | b | s | u | sub | sup | br">
		<xsl:element name="{lower-case(local-name())}">
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	
	<!-- Include Microsoft "keep lines together in cell" style attribute by setting priority = 1 [3b]; do not add by setting priority = -1 -->
	<!-- <br style="mso-data-placement:same-cell;"/> -->
	<xsl:template match="br" priority="1">
		<xsl:element name="br">
			<xsl:attribute name="style" select="'mso-data-placement:same-cell;'"/>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>

	<!-- As of .x5et., the templates shown below should not be needed any more, but just in case ... -->
	
	<!-- Remove underline _formatting_ by setting priority = 1 [3a]; retain by setting priority = -1 -->
	<xsl:template match="u" priority="1">
		<xsl:apply-templates/>
	</xsl:template>
		
	<!-- Remove strikethrough _text_ by setting priority = 1 [3a]; retain by setting priority = -1 -->
	<xsl:template match="s" priority="1"/>	

</xsl:stylesheet>
